.. django-babel documentation master file, created by
   sphinx-quickstart on Sat Feb 22 14:40:46 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

========================================
Welcome to django-babel's documentation!
========================================

.. include:: ../README.rst
.. include:: ../CHANGELOG.rst

Contents:

.. toctree::
   :maxdepth: 2

   extract
   management-commands
   middleware
   template-tags


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
